@@ -2,7 +2,6 @@ package Petal::Hash;
 use strict;
 use warnings;
 use Carp;
-use Petal::XML_Encode_Decode;
 
 our $MODIFIERS = {};
 
@@ -139,22 +138,15 @@ sub __FETCH
 	my $res = $self->fetch ($key);
 	if (defined $res and not ref $res)
 	{
-	    $res = $self->_xml_encode ($res);
+	    $res =~ s/\&/\&amp;/g;
+	    $res =~ s/\</\&lt;/g;
+	    $res =~ s/\"/\&quot;/g;
 	}
 	return $res;
     }
 }
 
 
-# encodes the 4 xml entities &amp; &lt; &gt; and &quot;.
-sub _xml_encode
-{
-    my $self = shift;
-    my $data = join '', @_;
-    return Petal::XML_Encode_Decode::encode ($data);
-}
-
-
 # this method fetches a Petal expression and returns it
 # without XML encoding. FETCH is basically a wrapper around
 # fetch() which looks for the special keyword 'structure'.
@@ -177,9 +169,9 @@ sub _fetch_mod
 {
     my $self  = shift;
     my $key   = shift;
-    my ($mod) = $key =~ /^(\S+?\:).*/;
+    my ($mod) = $key =~ /^([A-Za-z0-9_-]+?\:).*/;
     defined $mod || return 'var:';
-    return (defined $MODIFIERS->{$mod}) ? $mod : 'var:';
+    return $mod;
 }
 
 
